bat.attacks API documentation

# bat.attacks

This module implements Distributed Black-box Attacks against Deep Learning models.

Local Search:

- SimBA Attack (Guo et al., 2019)
- Square Attack (Andriushchenko et al., 2020)

Gradient Estimation:

- Bandits Attack (Ilyas et al., 2019)

#### bat.attacks.simba_attack

#### bat.attacks.square_attack

#### bat.attacks.bandits_attack

View Source

     1r'''
     2This module implements Distributed Black-box Attacks against Deep Learning models.
     3
     4Local Search:
     5
     6- SimBA Attack [(Guo et al., 2019)](https://arxiv.org/abs/1905.07121)
     7- Square Attack [(Andriushchenko et al., 2020)](https://arxiv.org/abs/1912.00049)
     8
     9Gradient Estimation:
    10
    11- Bandits Attack [(Ilyas et al., 2019)](https://arxiv.org/abs/1807.07978)
    12
    13#### bat.attacks.simba_attack
    14#### bat.attacks.square_attack
    15#### bat.attacks.bandits_attack
    16'''
    17
    18from bat.attacks.base_attack import BaseAttack
    19
    20from bat.attacks.simba_attack import SimBA
    21from bat.attacks.square_attack import SquareAttack
    22from bat.attacks.bandits_attack import BanditsAttack